@@ -36,7 +36,7 @@ def app(name="modpoll"):
     # setup mqtt
     if args.mqtt_host:
         log.info(f"Setup MQTT connection to {args.mqtt_host}")
-        if not mqttc_setup(args.mqtt_host, port=args.mqtt_port, user=args.mqtt_user, password=args.mqtt_pass, qos=1):
+        if not mqttc_setup(args.mqtt_host, port=args.mqtt_port, user=args.mqtt_user, password=args.mqtt_pass, qos=args.mqtt_qos):
             log.error("fail to setup MQTT client")
             mqttc_close()
             exit(1)
