@@ -170,7 +170,6 @@ class Poller:
             self.count_success(True)
             log.info(f"Reading device:{self.devid}, FuncCode:{self.functioncode}, "
                      f"Ref:{self.reference}, Size:{self.size}... SUCCESS")
-            # log.debug(f"Received DATA: {data}")
             return True
         except ModbusException as ex:
             self.count_success(False)
@@ -197,14 +196,12 @@ class Poller:
     def publish_data(self, timestamp=None, on_change=False):
         payload = {}
         for ref in self.readableReferences:
-            if not ref.val:
-                continue
             if on_change and ref.val == ref.last_val:
                 continue
             payload[f'{ref.name}|{ref.unit}'] = ref.val
         if timestamp:
             payload['timestamp'] = timestamp
-        topic = f"{args.mqtt_topic_prefix}{self.device.name}/state"
+        topic = f"{args.mqtt_topic_prefix}{self.device.name}"
         mqttc_publish(topic, json.dumps(payload))
 
 
@@ -216,8 +213,12 @@ class Reference:
         self.dtype = dtype
         if "int16" in dtype:
             self.length = 1
+        elif "uint16" in dtype:
+            self.length = 1
         elif "int32" in dtype:
             self.length = 2
+        elif "uint32" in dtype:
+            self.length = 2
         elif "float32" == dtype:
             self.length = 2
         elif "bool" == dtype:
@@ -254,9 +255,6 @@ class Reference:
                 pass
         self.lastval = self.val
         self.val = v
-        # if self.lastval != val or always_publish:
-        #     name = f"{args.mqtt_name}{self.device.name}/state/{self.name}"
-        #     mqttc_publish(name, str(val))
 
 
 def load_config(file):
@@ -358,7 +356,7 @@ def modbus_poll():
                 p.publish_data()
             while time.time() < t + args.interval:
                 time.sleep(0.001)
-    # master.close()
+    master.close()
     for d in deviceList:
         d.publish_diagnostics()
 
